/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef PWS2CRYPT_H
#define PWS2CRYPT_H 1

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <assert.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include "config.h"
#include "secmem.h"
#include "pws.h"

#ifdef MINGW32
#include "mingw.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

#define PWS2_MAC_SIZE       20
#define PWS2_IP_SIZE        8
#define PWS2_BLOCK_SIZE     8

/**
 * Decrypts the pws2 file and stores the decrypted typed field block inside
 * buf.
 *
 * @param pws2  - The pws2_t context.
 * @param buf   - The pws_buffer_t object.
 * @param f     - The PWSv2 FILE object.
 * @param error - The pws_error_t object.
 *
 * @returns 1 on success, otherwise 0 and error->error will be set to the corresponding error code.
 */
#ifdef MINGW32
EXPORT
#endif
int pws2_dec_file (pws2_t *pws2, pws_buffer_t *buf, FILE *f, pws_error_t *error);

/**
 * Enycrypts all data inside the pws_buffer_t object and writes
 * a PWSv2 file using the FILE object f.
 *
 * @param pws2  - The pws2_t object.
 * @param buf   - The pws_buffer_t object.
 * @param f     - The FILE object.
 * @param error - The pws_error_t object.
 *
 * @returns 1 on success, otherwise 0 and error->error will be set to the corresponding error code.
 */
#ifdef MINGW32
EXPORT
#endif
int pws2_enc_file (pws2_t *pws2, pws_buffer_t *buf, FILE *f, pws_error_t *error);

/**
 * Calculates H(RND) and stores the result in hrnd. pws2->rnd and
 * pws2->p needs to already set.
 *
 * @param pws2  - The pws2_t object.
 * @param hrnd  - The buffer were H(RND) will be stored.
 * @param error - The pws_error_t object.
 *
 * @returns 1 on success, otherwise 0.
 */
#ifdef MINGW32
EXPORT
#endif
int pws2_calc_hrnd (pws2_t *pws2, unsigned char * hrnd, pws_error_t *error);

/**
 * Calculates the key which is used for encryption.
 *
 * @param pws2  - The pws2_t object.
 *
 * @param pws2 - The pws2_t context.
 */
#ifdef MINGW32
EXPORT
#endif
void pws2_calc_key (pws2_t *pws2);

#ifdef __cplusplus
}
#endif

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
